@@ -30,14 +30,14 @@
  * Authors: Federico Mena <federico@nuclecu.unam.mx>
  */
 #include <config.h>
-#include <libgnome/gnome-macros.h>
-
+#include <sys/param.h>
 #include <pwd.h>
 #include <string.h>
 #include <unistd.h>
-#include <sys/param.h>
 #include <sys/types.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
+
+#include <libgnome/gnome-macros.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkentry.h>
@@ -544,7 +544,7 @@ gnome_file_entry_destroy (GtkObject *object)
 		gtk_widget_destroy (fentry->fsw);
 	fentry->fsw = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -566,7 +566,7 @@ gnome_file_entry_finalize (GObject *object)
 	g_free (fentry->_priv);
 	fentry->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /**
