@@ -55,7 +55,7 @@
 
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-config.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 
 #include "gnome-file-entry.h"
 #include "gnome-icon-list.h"
@@ -77,8 +77,6 @@ struct _GnomeIconEntryPrivate {
 	gchar *browse_dialog_title;
 };
 
-static void gnome_icon_entry_class_init (GnomeIconEntryClass *class);
-static void gnome_icon_entry_instance_init (GnomeIconEntry      *ientry);
 static void drag_data_get		(GtkWidget          *widget,
 					 GdkDragContext     *context,
 					 GtkSelectionData   *selection_data,
@@ -123,7 +121,7 @@ enum {
 static gint gnome_ientry_signals[LAST_SIGNAL] = {0};
 
 GNOME_CLASS_BOILERPLATE (GnomeIconEntry, gnome_icon_entry,
-			 GtkVBox, gtk_vbox, GTK_TYPE_VBOX)
+			 GtkVBox, GTK_TYPE_VBOX)
 static void
 gnome_icon_entry_class_init (GnomeIconEntryClass *class)
 {
@@ -409,7 +407,7 @@ ientry_destroy (GtkObject *object)
 		gtk_widget_destroy (ientry->_priv->pick_dialog);
 	ientry->_priv->pick_dialog = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -434,7 +432,7 @@ ientry_finalize (GObject *object)
 	g_free (ientry->_priv);
 	ientry->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
@@ -705,6 +703,7 @@ drag_data_received (GtkWidget        *widget,
 {
 	GList *uris, *li;
 	GnomeVFSURI *uri = NULL;
+	GnomeVFSFileInfo *file_info;
 
 	/*here we extract the filenames from the URI-list we recieved*/
 	uris = gnome_vfs_uri_list_parse (selection_data->data);
@@ -722,7 +721,12 @@ drag_data_received (GtkWidget        *widget,
 		}
 
 		path = gnome_vfs_uri_get_path (uri);
-		mimetype = gnome_vfs_get_mime_type_from_file_data (uri);
+		file_info = gnome_vfs_file_info_new ();
+		/* FIXME: OK to do synchronous I/O on a possibly-remote URI here? */
+		gnome_vfs_get_file_info_uri (uri, file_info,
+					     GNOME_VFS_FILE_INFO_GET_MIME_TYPE | 
+					     GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+		mimetype = gnome_vfs_file_info_get_mime_type (file_info);
 
 		if (mimetype != NULL &&
 		    strcmp (mimetype, "application/x-gnome-app-info") == 0) {
@@ -784,11 +788,14 @@ drag_data_received (GtkWidget        *widget,
 				g_free (full);
 			}
 		} else if (gnome_icon_entry_set_filename (ientry, path)) {
+			gnome_vfs_file_info_unref (file_info);
 			break;
 		}
 		uri = NULL;
+		gnome_vfs_file_info_unref (file_info);
 	}
 
+
 	/*if there's isn't a file*/
 	if (uri == NULL) {
 		gtk_drag_finish (context, FALSE, FALSE, time);
