@@ -59,9 +59,6 @@ struct _GnomeIconSelectionPrivate {
 	GtkWidget * load_progressbar;
 };
 
-static void gnome_icon_selection_class_init (GnomeIconSelectionClass *klass);
-static void gnome_icon_selection_instance_init (GnomeIconSelection   *gis);
-
 static void gnome_icon_selection_destroy    (GtkObject               *object);
 static void gnome_icon_selection_finalize   (GObject                 *object);
 
@@ -69,7 +66,7 @@ static int sort_file_list		    (gconstpointer            a,
 					     gconstpointer            b);
 
 GNOME_CLASS_BOILERPLATE (GnomeIconSelection, gnome_icon_selection,
-			 GtkVBox, gtk_vbox, GTK_TYPE_VBOX)
+			 GtkVBox, GTK_TYPE_VBOX)
 
 static void
 gnome_icon_selection_class_init (GnomeIconSelectionClass *klass)
@@ -123,6 +120,11 @@ gnome_icon_selection_instance_init (GnomeIconSelection *gis)
 	gtk_container_add (GTK_CONTAINER (frame), gis->_priv->gil);
 	gtk_widget_show(gis->_priv->gil);
 
+	gtk_signal_connect (GTK_OBJECT (gis->_priv->gil), "destroy",
+			    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+			    &(gis->_priv->gil));
+
+
 	gis->_priv->file_list = NULL;
 }
 
@@ -163,7 +165,7 @@ gnome_icon_selection_destroy (GtkObject *object)
 	    g_main_loop_is_running (gis->_priv->load_loop))
 		g_main_loop_quit (gis->_priv->load_loop);
 
-	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 
@@ -187,7 +189,7 @@ gnome_icon_selection_finalize (GObject *object)
 	g_free (gis->_priv);
 	gis->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /**
@@ -450,14 +452,13 @@ gnome_icon_selection_show_icons (GnomeIconSelection * gis)
 
 	gis->_priv->load_progressbar = NULL;
 
-	if ( ! GTK_OBJECT_DESTROYED (gis)) {
+	if (gis->_priv->gil != NULL)
 		gnome_icon_list_thaw (GNOME_ICON_LIST (gis->_priv->gil));
 
-		if (progressbar != NULL)
-			gtk_widget_destroy (progressbar);
-		if (label != NULL)
-			gtk_widget_destroy (label);
-	}
+	if (progressbar != NULL)
+		gtk_widget_destroy (progressbar);
+	if (label != NULL)
+		gtk_widget_destroy (label);
 
 	gtk_object_unref (GTK_OBJECT (gis));
 }
