@@ -54,7 +54,7 @@
 #include "gnome-pixmap-entry.h"
 #include "gnome-pixmap.h"
 
-#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
 
 struct _GnomePixmapEntryPrivate {
 	GtkWidget *preview;
@@ -67,8 +67,6 @@ struct _GnomePixmapEntryPrivate {
 };
 
 
-static void gnome_pixmap_entry_class_init (GnomePixmapEntryClass *class);
-static void gnome_pixmap_entry_instance_init (GnomePixmapEntry      *pentry);
 static void drag_data_get		  (GtkWidget          *widget,
 					   GdkDragContext     *context,
 					   GtkSelectionData   *selection_data,
@@ -100,8 +98,7 @@ enum {
 };
 
 GNOME_CLASS_BOILERPLATE (GnomePixmapEntry, gnome_pixmap_entry,
-			 GnomeFileEntry, gnome_file_entry,
-			 GNOME_TYPE_FILE_ENTRY)
+			 GnomeFileEntry, GNOME_TYPE_FILE_ENTRY)
 
 static void
 gnome_pixmap_entry_class_init (GnomePixmapEntryClass *class)
@@ -330,7 +327,7 @@ pentry_destroy (GtkObject *object)
 
 	changed_pentries = g_slist_remove (changed_pentries, pentry);
 
-	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -349,7 +346,7 @@ pentry_finalize (GObject *object)
 	g_free (pentry->_priv);
 	pentry->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
